@@ -39,12 +39,16 @@ class cluster(object):
         def delete_cluster(uri):
             return cluster.Cluster(self, method='delete', uri=uri)
 
+        def upgrade_cluster(uri):
+            return cluster.Cluster(self, method='post', uri=uri)
+
         _function_mapping = {
             'get': get_cluster,
             'getv2': getv2_cluster,
             'add': add_cluster,
             'edit': edit_cluster,
-            'delete': delete_cluster
+            'delete': delete_cluster,
+            'upgrade': upgrade_cluster
         }
 
         self.uri = {
@@ -52,7 +56,8 @@ class cluster(object):
             getv2_cluster: 'api/v2/cluster',
             add_cluster: 'api/v1/cluster',
             edit_cluster: 'api/v1/cluster/{clusterId}',
-            delete_cluster: 'api/v1/cluster/{clusterId}'
+            delete_cluster: 'api/v1/cluster/{clusterId}',
+            upgrade_cluster: 'api/v1/cluster/{clusterId}/upgrade'
         }
 
         self.payload = resourcePaylod.Cluster(payload).__dict__
@@ -134,3 +139,7 @@ class cluster(object):
     @staticmethod
     def get(cluster_id):
         return cluster(action='get', cluster_id=cluster_id)
+
+    @staticmethod
+    def upgrade(cluster_id, policy=None):
+        return cluster(action='upgrade', cluster_id=cluster_id, payload=locals())
