@@ -61,6 +61,9 @@ class node(object):
         def statssummary_inode(uri):
             return node.Stats(self, method='stats', uri=uri, filters=filters)
 
+        def upgrade_inode(uri):
+            return node.iNode(self, method='post', uri=uri)
+
         _function_mapping = {
             'add': add_inode,
             'edit': edit_inode,
@@ -71,7 +74,8 @@ class node(object):
             'getv2': getv2_inode,
             'notifications': notifications_inode,
             'stats':stats_inode,
-            'statssummary':statssummary_inode
+            'statssummary':statssummary_inode,
+            'upgrade': upgrade_inode
         }
 
         self.uri = {
@@ -85,6 +89,7 @@ class node(object):
             notifications_inode:'api/v2/notification/node/{nodeId}/event',
             stats_inode:'api/v1/report/node/{nodeId}/stats',
             statssummary_inode: 'api/v1/report/node/{nodeId}/stats',
+            upgrade_inode: 'api/v1/node/{nodeId}/upgrade'
         }
 
         self.payload = resourcePaylod.iNode(payload).__dict__
@@ -223,4 +228,7 @@ def stats(node_id):
     return node(node_id=node_id, action="stats")
 
 def statssummary(node_id):
-    return node(node_id=node_id, action="statssummary")
\ No newline at end of file
+    return node(node_id=node_id, action="statssummary")
+
+def upgrade(node_id, policy=None):
+    return node(action='upgrade', node_id=node_id, payload=locals())
