@@ -1742,8 +1742,9 @@ class resourcePaylod(object):
                 self.action = action
                 self.protocol = "HTTPS"
                 if 'username' in payload['params']:
-                    self.url = "{}@{}".format(payload['params']['username'], payload['params']['url'])
+                    self.url = "{}".format(payload['params']['url'])
                     self.password = payload['params']['password']
+                    self.username = payload['params']['username']
                 else:
                     self.url = payload['params']['url']
             if action == "unset" and payload['command'] == "proxy":
